
/* ----------------------------------------------------------------------
   The SINUS Firewall -- a TCP/IP packet filter for Linux

   Written within the SINUS project at the University of Zurich,
   SWITCH, Telekurs Payserv AG, ETH Zurich.
   originally based on the sf Firewall Software (C) 1996 by Robert
   Muchsel and Roland Schmid.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   SINUS Firewall resources:
   SINUS Homepage: http://www.ifi.unizh.ch/ikm/SINUS/
   Firewall Homepage: http://www.ifi.unizh.ch/ikm/SINUS/firewall.html
   Frequently asked questions: http://www.ifi.unizh.ch/ikm/SINUS/sf_faq.html
   Mailing list for comments, questions, bug reports: firewall@ifi.unizh.ch
   ----------------------------------------------------------------------  */



package sfclasses;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * This class is used for graphically displaying and drag-and-drop editing
 * of graphs. Vertex objects must implement DragDropObj. <br>
 * The drag and drop panel consists of a canvas to display and edit the
 * topology, two scrollbars and a status line. Object dependent methods
 * are defined in DragDropObj. <br>
 * This is a GUI class.
 * @see DragDropObj
 * @see Graph
 * @version 1.0 29 Nov 1996
 * @author Roland E. Schmid
 */

public class DragDrop
	extends Panel
	implements AdjustmentListener, MouseListener,
						 MouseMotionListener, KeyListener {

  /**
   * Create a canvas and two scrollbars and lay them out in the panel
   * @param g graph to store objects and edges
   * @param newObjectClass class for object creation 
   * (must be public and implement DragDropObj)
   */
  public DragDrop(Graph g, Class newObjectClass) {
    // implicit super() call here creates the panel
    createClass = newObjectClass;
    graph = g;
    canvas = new DragDropCanvas();
		canvas.addMouseListener(this);
		canvas.addMouseMotionListener(this);
		canvas.addKeyListener(this);
    hbar = new Scrollbar(Scrollbar.HORIZONTAL);
    vbar = new Scrollbar(Scrollbar.VERTICAL);
		hbar.addAdjustmentListener(this);
		vbar.addAdjustmentListener(this);

    GridBagLayout gbl = new GridBagLayout();
    GridBagConstraints gbc = new GridBagConstraints();
    gbc.fill = GridBagConstraints.BOTH;
    setLayout(gbl);

    sp = new Panel();
    sp.setLayout(new BorderLayout(0,0));
    sp.add("Center", canvas);
    sp.add("South", hbar);
    sp.add("East", vbar);
    Utils.add_component(this, sp, gbl, gbc, 0, 0, 1, 1, 100, 100);    

    status = new Label("");
    Utils.add_component(this, status, gbl, gbc, 0, 1, 1, 1, 100, 0);
    mt = new MediaTracker(canvas);
  }

  /** 
   * Create a canvas and two scrollbars and lay them out in the panel
   * @param g graph to store objects and edges
   * @param newObjectClass class for object creation
   * (must be public and implement DragDropObj)
   * @param edit enable / disable editing functions on startup
   */
  public DragDrop(Graph g, Class newObjectClass, boolean edit) {
    this(g, newObjectClass);
    editEnabled = edit;
  }

  /** 
   * Event handler <br>
   * mouse click on background creates new object<br>
   * left mouse button to draw lines<br>
   * right mouse button (or button + META) to drag objects<br>
   * double click on object to call object's execute() method
   */

	public void adjustmentValueChanged(AdjustmentEvent ae) {
	Object source = ae.getAdjustable();
	int whatkind = ae.getAdjustmentType();

    Graphics canvas_g = canvas.getGraphics();
    if (canvas_g == null)
      return;
    canvas_g.setXORMode(canvas.getBackground());

    if (source == hbar) { // horizontal scroll bar
      switch(whatkind) {
        case AdjustmentEvent.UNIT_INCREMENT:
          offset_x = ae.getValue();
          break;
        case AdjustmentEvent.UNIT_DECREMENT:
          offset_x = ae.getValue();
          break;
        case AdjustmentEvent.BLOCK_INCREMENT:
        case AdjustmentEvent.BLOCK_DECREMENT:
        case AdjustmentEvent.TRACK:
          offset_x = ae.getValue();
          break;
      }
      canvas.repaint();
      canvas_g.dispose();
      return;
    }
    else if (source == vbar) { // vertical scroll bar
      switch(whatkind) {
        case AdjustmentEvent.UNIT_INCREMENT:
          offset_y = ae.getValue();
          break;
        case AdjustmentEvent.UNIT_DECREMENT:
          offset_y = ae.getValue();
          break;
        case AdjustmentEvent.BLOCK_INCREMENT:
        case AdjustmentEvent.BLOCK_DECREMENT:
        case AdjustmentEvent.TRACK:
          offset_y = ae.getValue();
          break;
      }
      canvas.repaint();
      canvas_g.dispose();
      return;
    }
	} // adjustmentValueChanged
		
	public void mouseClicked(MouseEvent me) {}
	public void mouseExited(MouseEvent me) {}
	public void mousePressed(MouseEvent me) {
    Graphics canvas_g = canvas.getGraphics();
    if (canvas_g == null)
      return;
    canvas_g.setXORMode(canvas.getBackground());

      int x = me.getX() + offset_x;
      int y = me.getY() + offset_y;

      DragDropObj v = find(x, y, orig_v);

			if ((selected) && (v != last_v)) { // deselect last_v
				last_v.highlight(canvas_g, offset_x, offset_y, false);
				selected = false;
				status.setText("");
			}

			if (v != null) { // user clicked on object
				if (!selected) {
					v.highlight(canvas_g, offset_x, offset_y, true);
					selected = true;
					status.setText(v.getObjectID());
				}
				if (!editEnabled) {
					if (me.getClickCount() > 1) {
						// double click
						v.userAction(Utils.getParentFrame(this),
												 canvas_g, offset_x, offset_y);
						checkConnection(v);
					}
					last_v = v;
					canvas_g.dispose();
					return;
				}
				// assert(editEnabled)
				if (me.getClickCount() > 1) {
					// double click
					v.execute(this);
					checkConnection(v);
				}
				else { // single click
					if (me.isMetaDown()) { // right button
						state = STATE_DRAG;
						orig_v = v;
					}
					else {
						state = STATE_DRAW;
						orig_v = v;
						orig_x = v.getX();
						orig_y = v.getY();
					}
				}
				last_x = v.getX();
				last_y = v.getY();
			}
			else { // v == null
				if (!editEnabled) {
					canvas_g.dispose();
					return;
				}
				// create new vertex
				try {
					v = (DragDropObj)createClass.newInstance();
					v.initImage(canvas, mt);
					boolean interrupted = true;
					while (interrupted) {
						try {
							mt.waitForAll();
							interrupted = false;
						}
						catch (Exception ex) {
							System.out.println("DragDrop.handleEvent: MediaTracker.waitForAll Exception "+ex);
						}
					}
					v.setCoordinates(x, y);
					v.draw(canvas_g, offset_x, offset_y);
					graph.insertVertex(v);
				}
				catch (IllegalAccessException e1) {
					System.out.println("Cannot create object, class not accessible: " +createClass);
				}
				catch (InstantiationException e2) {
					System.out.println("Cannot create object, class is interface or abstract: "+createClass);
				}
				catch (ClassCastException e3) {
System.out.println("Cannot create object, class does not implement DragDropObj: "+createClass);
				}
				last_x = x;
				last_y = y;
			}
			last_v = v;
			
			canvas_g.dispose();
			return;
	} // mousePressed


	public void mouseReleased(MouseEvent me) {

    Graphics canvas_g = canvas.getGraphics();
    if (canvas_g == null)
      return;
    canvas_g.setXORMode(canvas.getBackground());

      int x = me.getX() + offset_x;
      int y = me.getY() + offset_y;
      DragDropObj v = find(x, y, orig_v);

			if (!dragged) {
				state = STATE_NONE;
				orig_v = null;
				canvas_g.dispose();
				return;
			}
			dragged = false;

			if (state == STATE_DRAG) { // user is dragging object
				if (v == null) {
					moveto(canvas_g, last_v, x, y);
				}
				else { // don't place object on top of other object
					moveto(canvas_g, last_v, last_x, last_y);
				}
				state = STATE_NONE;
			}

			if (state == STATE_DRAW) { // user is drawing line
				if ((last_x != orig_x) || (last_y != orig_y)) { // erase line
					canvas_g.drawLine(orig_x - offset_x, orig_y - offset_y, 
														last_x - offset_x, last_y - offset_y);
				}
				if (orig_v.canConnectTo(v)) {
					// deselect last_v
					if ((last_v != orig_v) && (last_v != null))
						last_v.highlight(canvas_g, offset_x, offset_y, false);

					if (v != null) { // insert or delete edge (toggle)
						// draw line (XOR-Mode -> erase or delete)
						if (graph.searchEdge(orig_v, v)) {
							// edge exists -> delete edge
							drawEdge(canvas_g,orig_v, v);
							graph.deleteEdge(orig_v, v);
						}
						else {
							// edge does not exist -> insert edge
							graph.insertEdge(orig_v, v, Color.black);
							drawEdge(canvas_g,orig_v, v);
							checkConnection(orig_v);
						}
					}
				}
				// can not connect origin to destination object
				else {
					orig_v.connectError(Utils.getParentFrame(this));
				}

				last_v = orig_v;
				last_x = orig_x;
				last_y = orig_y;
				state = STATE_NONE;
			}

			orig_v = null;
			canvas_g.dispose();
			return;
	} // mouseReleased


	public void mouseMoved(MouseEvent me) {}
	public void mouseDragged(MouseEvent me) {
	int X = me.getX();
	int Y = me.getY();

    Graphics canvas_g = canvas.getGraphics();
    if (canvas_g == null)
      return;
    canvas_g.setXORMode(canvas.getBackground());

		int x = X + offset_x;
		int y = Y + offset_y;
		DragDropObj v = find(x, y, orig_v);

		if (state == STATE_DRAG) { // user is dragging object
			if (X < 0 || X >= canvas_width || 
					Y < 0 || Y >= canvas_height)
				updateVirtual(X, Y, true, false);
			moveto(canvas_g, last_v, x, y);
			dragged = true;
		}

		if (state == STATE_DRAW) { // user is drawing line
			dragged = true;
			if ((last_x != orig_x) || (last_y != orig_y)) { // erase line
				canvas_g.drawLine(orig_x - offset_x, orig_y - offset_y, 
													last_x - offset_x, last_y - offset_y);
			}
			if (X < 0 || X >= canvas_width ||
					Y < 0 || Y >= canvas_height) 
				updateVirtual(X, Y, false, true);
			if (last_v != v) {
				// deselect last_v
				if ((last_v != orig_v) && (last_v != null))
					last_v.highlight(canvas_g, offset_x, offset_y, false);
				// select v
				if (v != null) 
					if (orig_v.canConnectTo(v))
						v.highlight(canvas_g, offset_x, offset_y, true);
			}
			// draw new line
			canvas_g.drawLine(orig_x - offset_x, orig_y - offset_y, 
												x - offset_x, y - offset_y);
			last_v = v;
			last_x = x;
			last_y = y;  
		}

		canvas_g.dispose();
		return;
	} // mouseDragged


	public void mouseEntered(MouseEvent me) {

		// update status line
		DragDropObj ddotmp = getSelected();
		if (ddotmp != null) 
			status.setText(ddotmp.getObjectID());
		return;
	} // mouseEntered



	public void keyTyped(KeyEvent ke) {}
	public void keyReleased(KeyEvent ke) {}
	public void keyPressed(KeyEvent ke) {

    Graphics canvas_g = canvas.getGraphics();
    if (canvas_g == null)
      return;
    canvas_g.setXORMode(canvas.getBackground());
		
		if (ke.getKeyCode() == KeyEvent.VK_ESCAPE) { // Esc pressed

			if (state == STATE_DRAG) { // user is dragging object
				moveto(canvas_g, last_v, last_x, last_y);
				orig_v = null;
				dragged = false;
				state = STATE_NONE;
			}

			if (state == STATE_DRAW) { // user is drawing line
				if ((last_x != orig_x) || (last_y != orig_y)) { // erase line
					canvas_g.drawLine(orig_x - offset_x, orig_y - offset_y, 
														last_x - offset_x, last_y - offset_y);
				}
				// deselect last_v
				if ((last_v != orig_v) && (last_v != null))
					last_v.highlight(canvas_g, offset_x, offset_y, false);

				state = STATE_NONE;
				last_v = orig_v;
				last_x = orig_x;
				last_y = orig_y;
				orig_v = null;
				dragged = false;
			}
		}
		
		// delete pressed -> delete highlighted vertex
		else if (ke.getKeyCode() == 127) {
			if (!editEnabled) {
				canvas_g.dispose();
				return;
			}
			if ((state == STATE_NONE) && (last_v != null) && selected) {
				// let's first check if the user has changed his mind
				if (!last_v.confirmDelete()) {
					canvas_g.dispose();
					return;
				}
				// deselect vertex
				last_v.highlight(canvas_g, offset_x, offset_y, false);
				selected = false;
				status.setText("");
				// erase edges
				Enumeration neighbors = graph.findNeighbors(last_v);
				DragDropObj n;
				while (neighbors.hasMoreElements()) {
					n = (DragDropObj)neighbors.nextElement();
					drawEdge(canvas_g,last_v, n);
				}
				// erase vertex
				last_v.erase(canvas_g, offset_x, offset_y);
				// delete vertex from graph
				graph.deleteVertex(last_v);
			}
		}
		
		// else if (e.key == 63) // `?' pressed
		// System.out.println("DragDrop: graph "+graph); 

		canvas_g.dispose();
		return;
	} // keyPressed



	/** 
   * Called when panel size changes (e.g. on startup)
   */
  public synchronized void setBounds(int x, int y, int width, int height) {
    // call setBounds() of superclass
    super.setBounds(x, y, width, height);

    // calculate virtual canvas size
    int hbar_size = hbar.getValue();
    int vbar_size = vbar.getValue();
    canvas_width = width - vbar_size;
    canvas_height = height - hbar_size;
    max_x = canvas_width;
    max_y = canvas_height;
    if (offset_x > max_x - canvas_width)
      offset_x = max_x - canvas_width;
    if (offset_y > max_y - canvas_height)
      offset_y = max_y - canvas_height;
    Enumeration vertices = graph.getAllVertices();
    DragDropObj v;
    while (vertices.hasMoreElements()) {
      v = (DragDropObj)vertices.nextElement();
      v.initImage(canvas, mt);
      int offset;
      int vx = v.getX()+10;
      if (vx > max_x) {
        offset = vx - max_x;
        if (canvas_width >= 2) {
          offset = (int)Math.ceil((double)offset / (double)(canvas_width / 2));
          max_x += offset * (canvas_width / 2);
        }
        else
          max_x = vx;
      }
      int vy = v.getY()+10;
      if (vy > max_y) {
        offset = vy - max_y;
        if (canvas_height >= 2) {
          offset = (int)Math.ceil((double)offset / (double)(canvas_height / 2));
          max_y += offset * (canvas_height / 2);
        }
        else
          max_y = vy;
      }
    }
    boolean interrupted = true;
    while (interrupted) {
      try {
        mt.waitForAll();
        interrupted = false;
      }
      catch (Exception ex) {
        System.out.println("DragDrop.reshape: MediaTracker.waitForAll Exception "+ex);
      }
    }

    // initialize scrollbars
    updateScrollbars(width, height);

  }

  /** 
   * Enable editing functions
   */
  public void enableEdit() {
    if ((last_v != null) && selected) {
      Graphics canvas_g = canvas.getGraphics();
      canvas_g.setXORMode(canvas.getBackground());
      last_v.highlight(canvas_g, offset_x, offset_y, false);
      canvas_g.dispose();
      selected = false;
      status.setText("");
    }
		checkConsistency();
    canvas.repaint();
    editEnabled = true;
  }

  /** 
   * Diable editing functions
   * @return true if successful, false if state != STATE_NONE
   */
  public boolean disableEdit() {
    if (state != STATE_NONE)
      return false;
		checkConsistency();
    if ((last_v != null) && selected) {
      Graphics canvas_g = canvas.getGraphics();
      canvas_g.setXORMode(canvas.getBackground());
      last_v.highlight(canvas_g, offset_x, offset_y, false);
      canvas_g.dispose();
      selected = false;
      status.setText("");
    }
    editEnabled = false;
    orig_v = null;
    return true;
  }


	/**
	 * Check consistency of topology.
	 * To be called when topology editor is left or a new
	 * topology has been loaded.
	 * @see checkConfig
	 * @see checkConnections
	 * @see checkForDuplicates
	 */
	public void checkConsistency() {
		graph.isConsistent = true;
		checkConfig();
		checkForDuplicates();
	}

  /** 
   * Get highlighted object
   * @return selected object or null if no object has been selected
   */
  public DragDropObj getSelected() {
    if ((state == STATE_NONE) && (last_v != null) && selected) 
      return last_v;
    else
      return null;
  }

  /**
   * Set the class for creation of new objects
   * @param newObjectClass class for object creation
   */
  public void setClass(Class newObjectClass) {
    createClass = newObjectClass;
  }

  /** 
   * Get graph object; note that you have to call repaint() 
   * after making changes in the graph topology manually
   * @return graph object
   * @see Graph
   */
  public Graph getGraph() {
    return graph;
  }

	public Graphics getCanvasGraphics() {
		return canvas.getGraphics();
	}


  // private methods


	/**
	 * Checks the configuration of all vertices by calling
	 * the checkConfig() methode.
	 * Icons are updated accordingly to indicate wether the
	 * specific configuration for an object represented by that icon
	 * is valid or not.
	 * @see DragDropObj
	 */
	private void checkConfig() {

		Enumeration en = graph.getAllVertices();
		DragDropObj ddo = null;

		boolean interrupted = true;
		while (interrupted) {
			try {
				mt.waitForAll();
				interrupted = false;
			}
			catch (Exception ex) {
				System.out.println("DragDrop.handleEvent: MediaTracker.waitForAll Exception "+ex);
			}
		}

		while (en.hasMoreElements()) {
			ddo = (DragDropObj)en.nextElement();
			if (ddo instanceof Host) {
				if (((Host)ddo).checkConfig())
					((Host)ddo).setOKIcon(this);
				else {
					((Host)ddo).setNOKIcon(this);
					graph.isConsistent = false;
				}
			}
			if (ddo instanceof Net) {
				if (((Net)ddo).checkConfig())
					((Net)ddo).setOKIcon(this);
				else {
					((Net)ddo).setNOKIcon(this);
					graph.isConsistent = false;
				}
			}
			checkConnection(ddo);
		}
	} // checkConfig


	/**
	 * Check if connections from Object ddo to all of its neighbours
	 * are valid or not. (i.e. sub-net addresses are valid)
	 * If a connection is not valid, the appropriate edge will be
	 * marked as 'not valid' (i.e. red color edge).
	 * @param DragDropObj Object to check.
	 */
	private void checkConnection(DragDropObj ddo) {

    Graphics canvas_g = canvas.getGraphics();
    Enumeration neighbors = graph.findNeighbors(ddo);
    DragDropObj n;
    while (neighbors.hasMoreElements()) {
      n = (DragDropObj)neighbors.nextElement();
      drawEdge(canvas_g, ddo, n);
			if (!checkNetAddresses(ddo, n)) {
				graph.setEdgeColor(ddo, n, Color.red);
				graph.isConsistent = false;
			}
			else
				graph.setEdgeColor(ddo, n, Color.black);
			drawEdge(canvas_g, ddo, n);
    }

	return;
	} // checkConnection


	/**
	 * Checks wether the address of object V1 and V1 are in the same
	 * sub-net or not.
	 * @param DragDropObj V1
	 * @param DragDropObj V2
	 * @return true if objects are in the same sub-net, false otherwise
	 */
	private boolean checkNetAddresses(DragDropObj V1, DragDropObj V2) {
		if ((V1 instanceof Internet) || (V2 instanceof Internet))
			return true;

		AddrList V1AddrList = null;
		AddrList V2AddrList = null;
		AddrObj ao1, ao2;
		Enumeration en1, en2;
		byte net1[] = new byte[4];
		byte net2[] = new byte[4];
		
		if (V1 instanceof Host)
			V1AddrList = ((Host)V1).HostAddresses;
		if (V1 instanceof Net)
			V1AddrList = ((Net)V1).NetAddresses;
		if (V2 instanceof Host)
			V2AddrList = ((Host)V2).HostAddresses;
		if (V2 instanceof Net)
			V2AddrList = ((Net)V2).NetAddresses;
		if ((V1AddrList == null) || (V2AddrList == null))
			return true;

		en1 = V1AddrList.getAddresses().elements();
		// outer loop
		while (en1.hasMoreElements()) {
			ao1 = (AddrObj)en1.nextElement();
		
			en2 = V2AddrList.getAddresses().elements();
			// inner loop
			while (en2.hasMoreElements()) {
      	ao2 = (AddrObj)en2.nextElement();
				net1 = AddrObj.And(ao1.getAddr(), ao2.getMask());
				net2 = AddrObj.And(ao2.getAddr(), ao1.getMask());
				if (AddrObj.equalIP(net1, net2))
					return true;
			} //inner loop
		} // outer loop
		
		return false;
	} // checkNetAddresses

	/**
	 * Check if all objects have unique addresses (i.e. no address
	 * has been assigned twice).
	 * If a duplicate has been found, the involved icons are set
	 * accordingly to indicate, that the configuration of those
	 * icons is not valid.
	 */
	private void checkForDuplicates() {

		Enumeration graphEnum;
		Enumeration en;
		Vector addrCollection = new Vector(3,3);
		Vector objCollection = new Vector(3,3);
		Vector ddoAddresses;
		AddrObj ao1, ao2;
		DragDropObj ddo;
		IconObject io;

		graphEnum = graph.getAllVertices();
		while (graphEnum.hasMoreElements()) {
			ddo = (DragDropObj)graphEnum.nextElement();
			if (ddo instanceof Host)
				ddoAddresses = ((Host)ddo).HostAddresses.getAddresses();
			else if (ddo instanceof Net)
				ddoAddresses = ((Net)ddo).NetAddresses.getAddresses();
			else ddoAddresses = null;

			if (ddoAddresses != null) {
				en = ddoAddresses.elements();

				// for all addresses of object
				while (en.hasMoreElements()) {
					ao1 = (AddrObj)en.nextElement();
					
					// for all addresses collected so far
					for (int i = 0; i < addrCollection.size(); i++) {
						ao2 = (AddrObj)addrCollection.elementAt(i);
						if (ao1.equals(ao2)) {
							((IconObject)ddo).setNOKIcon(this);
							io = (IconObject)objCollection.elementAt(i);
							io.setNOKIcon(this);
							graph.isConsistent = false;
						}
					}
					addrCollection.addElement(ao1);
					objCollection.addElement(ddo);
				}
			}
		}
	} // checkForDuplicates

							
  private void updateScrollbars(int width, int height) {
    if (canvas_width >= 1 && canvas_height >= 1) {
      hbar.setValues(offset_x, canvas_width, 0, max_x - canvas_width);
      vbar.setValues(offset_y, canvas_height, 0, max_y - canvas_height);
      hbar.setBlockIncrement(canvas_width / 2);
      vbar.setBlockIncrement(canvas_height / 2);
      hbar.setUnitIncrement(canvas_width / 10);
      vbar.setUnitIncrement(canvas_height / 10);
    }
  }

  /**
   * Called to update the window when dragging objects or drawing lines
   * @param x current horizontal position
   * @param y current vertical position
   * @extend if true, the virtual size will be extended when moving out
   * @scroll if true, the panel scrolls so that the current position is visible
   */
  private void updateVirtual(int x, int y, boolean extend, boolean scroll) {
    int offset;

    // extend virtual size if necessary
    if (extend && ((x + offset_x) > max_x || (y + offset_y) > max_y)) {
      if ((x+offset_x) > max_x) {
        offset = x + offset_x - max_x;
        if (canvas_width >= 2) {
          offset = (int)Math.ceil((double)offset / (double)(canvas_width / 2));
          max_x += offset * (canvas_width / 2);
        }
        else
          max_x = x+offset_x+10;
      }
      if ((y+offset_y) > max_y) {
        offset = y + offset_y - max_y;
        if (canvas_height >= 2) {
          offset = (int)Math.ceil((double)offset / (double)(canvas_height / 2));
          max_y += offset * (canvas_height / 2);
        }
        else
          max_y = y+offset_y+10;
      }
      updateScrollbars(canvas_width, canvas_height);
    }

    // scroll to current position if necessary
    if (scroll) {
      int oldx = offset_x;
      int oldy = offset_y;
      if (x < 0) {
        offset = ((-x) / (canvas_width / 10)) + 1;
        offset_x -= offset * (canvas_width / 10);
        if (offset_x < 0)
          offset_x = 0;
      }
      if (y < 0) {
        offset = ((-y) / (canvas_height / 10)) + 1;
        offset_y -= offset * (canvas_height / 10);
        if (offset_y < 0)
          offset_y = 0;
      }
      if (x >= canvas_width) {
        offset = ((x - canvas_width) / (canvas_width / 10)) + 1;
        offset_x += offset * (canvas_width / 10);
        if (offset_x > max_x - canvas_width)
          offset_x = max_x - canvas_width;
      }
      if (y >= canvas_height) {
        offset = ((y - canvas_height) / (canvas_height / 10)) + 1;
        offset_y += offset * (canvas_height / 10);
        if (offset_y > max_y - canvas_height)
          offset_y = max_y - canvas_height;
      }  
      if (oldx != offset_x || oldy != offset_y) {
        hbar.setValue(offset_x);
        vbar.setValue(offset_y);
        Graphics canvas_g = canvas.getGraphics();
        canvas.update(canvas_g);
        canvas_g.dispose();
      }
    }
  }
  
  /**
   * Get object at the specified position. 
   * @param x Current horizontal position
   * @param y Current vertical position
   * @param except Object to ignore
   */
  private DragDropObj find(int x, int y, DragDropObj except) {
    Enumeration vertices = graph.getAllVertices();
    DragDropObj v;
    
    while (vertices.hasMoreElements()) {
      v = (DragDropObj)vertices.nextElement();
      if ((v != except) && (v.hasFocus(x,y)))
        return v;
    }
    return null;
  }

  /**
   * Move an object to a different position.
   * @param canvas_g Graphics context of canvas
   * @param obj Object to move
   * @param x New horizontal position
   * @param y New vertical position
   */
  private void moveto(Graphics canvas_g, DragDropObj obj, int x, int y) {
    Enumeration neighbors = graph.findNeighbors(obj);
    DragDropObj n;
    while (neighbors.hasMoreElements()) {
      n = (DragDropObj)neighbors.nextElement();
      drawEdge(canvas_g, obj, n);
    }

    obj.erase(canvas_g, offset_x, offset_y);
    obj.setCoordinates(x, y);
    obj.draw(canvas_g, offset_x, offset_y);

    neighbors = graph.findNeighbors(obj);
    while (neighbors.hasMoreElements()) {
      n = (DragDropObj)neighbors.nextElement();
      drawEdge(canvas_g, obj, n);
    }
  }

  /**
   * Draw edge between two objects.
   * @param g Graphics context
   * @param V1 First object
   * @param V1 Second object
   */
  protected void drawEdge(Graphics g, DragDropObj V1, DragDropObj V2) {
    Point v1_center = new Point(V1.getX(), V1.getY());
    Point v2_center = new Point(V2.getX(), V2.getY());
    Point v1_conn = V1.connectionCoord(v2_center);
    Point v2_conn = V2.connectionCoord(v1_center);

		Color ctxtcol = g.getColor();
		Color edgecol = graph.getEdgeColor(V1, V2);
		if (edgecol != null)
			g.setColor(edgecol);
    g.drawLine(v1_conn.x-offset_x, v1_conn.y-offset_y,
               v2_conn.x-offset_x, v2_conn.y-offset_y);
		g.setColor(ctxtcol);
  }

  // constants
  private static final int STATE_NONE = 0;
  private static final int STATE_DRAW = 1;
  private static final int STATE_DRAG = 2;

  // data
  protected Graph graph;		// graph to store vertices and edges
  protected int offset_x = 0;		// current scroll position (x)
	protected int offset_y = 0;   // current scroll position (y)
	private MediaTracker mt;    // MediaTracker
	private Class createClass;    // used to create new objects
	private DragDropCanvas canvas;  // drag and drop area
	private Scrollbar hbar, vbar;   // scrollbars
  private Panel sp;			// South Panel (Scrollbar + Status)
  private Label status;			// Status line
  private int last_x, last_y;		// last mouse pointer position
  private DragDropObj last_v;		// last selected object
  private int orig_x, orig_y;		// origin position for line drawing
  private DragDropObj orig_v;		// origin object for drawing and dragging
  private int max_x;			// x size of drag and drop area
  private int max_y;			// y size of drag and drop area
  private int canvas_width;		// width of currently visible area
  private int canvas_height;		// height of currently visible area
  private int state = STATE_NONE;	// state (see constants above)
  private boolean selected = false;	// is there any selected object?
  private boolean dragged = false;	// did user move the mouse since mouse-down?
  private boolean editEnabled = false;  // enable edit functions

} // DragDrop

// The class DragDropCanvas implements the drawing area of the panel.
class DragDropCanvas extends Canvas {

  public synchronized void paint(Graphics g) {
    if (g==null)
      return;
    DragDrop dd = (DragDrop)getParent().getParent();

    // erase screen
    Rectangle r = getBounds();
    g.clearRect(r.x, r.y, r.width, r.height);
    g.setXORMode(getBackground());

    // draw vertices
    Enumeration vertices = dd.graph.getAllVertices();
    DragDropObj v;
    while (vertices.hasMoreElements()) {
      v = (DragDropObj)vertices.nextElement();
      v.draw(g, dd.offset_x, dd.offset_y);
    }

    // draw edges
    Enumeration edges = dd.graph.getAllEdges();
    Edge e;
    while (edges.hasMoreElements()) {
      e = (Edge)edges.nextElement();
      dd.drawEdge(g, (DragDropObj)e.vertex1, (DragDropObj)e.vertex2);
    }      

    // request input focus
    requestFocus();
  }

  public void update(Graphics g) {
    paint(g);
  }

/*  public boolean gotFocus(Event evt, Object what) {
    return true;
  }
*/
} // DragDropCanvas
