
/* ----------------------------------------------------------------------
   The SINUS Firewall -- a TCP/IP packet filter for Linux

   Written within the SINUS project at the University of Zurich,
   SWITCH, Telekurs Payserv AG, ETH Zurich.
   originally based on the sf Firewall Software (C) 1996 by Robert
   Muchsel and Roland Schmid.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   SINUS Firewall resources:
   SINUS Homepage: http://www.ifi.unizh.ch/ikm/SINUS/
   Firewall Homepage: http://www.ifi.unizh.ch/ikm/SINUS/firewall.html
   Frequently asked questions: http://www.ifi.unizh.ch/ikm/SINUS/sf_faq.html
   Mailing list for comments, questions, bug reports: firewall@ifi.unizh.ch
   ----------------------------------------------------------------------  */



package sfclasses;

import java.awt.*;
import java.awt.event.*;
import java.net.*;
import java.util.*;
import java.io.*;
import com.sun.java.swing.*;

/**
 * This class implements host objects. It describes the properties
 * of general hosts, firewalls and servers. 
 * @version 1.0 03 Dec 1996
 * @author Roland E. Schmid
 */

public class Host
	extends IconObject {

  /**
   * Initialize host and host icon
   */
  public Host() {
    // implicit call to super()
		if(checkConfig()) // check consistency
			setOKIcon(null);
		else 
			setNOKIcon(null);

    hostTemplates = new boolean[Templates.numberServer + Templates.numberFirewall];
    for (int i=0; i < hostTemplates.length; i++)
      hostTemplates[i] = Templates.defaultActivate[i+Templates.startServer];
  }

  /**
   * Load the actual configuration data from the firewall
   * @return true if successful, false otherwise
   */
  public boolean loadDynamicConfig() {
    isLoaded = false;
    if (!Communicator.readFwConfig(this)) {
      if (Communicator.commError == Communicator.COMM_OK) {
        // retry once, server connection may be reestablished now
        if (!Communicator.readFwConfig(this))
          return false;
      }
      else
        return false;
    }
    isLoaded = true;
    return true;
  }

  /**
   * Load the active TCP connections from the firewall
   * @return true if successful, false otherwise
   */
  public boolean loadTcpConns() {
    if (!Communicator.readTcpConns(this)) {
      if (Communicator.commError == Communicator.COMM_OK) {
        // retry once, server connection may be reestablished now
        if (!Communicator.readTcpConns(this))
          return false;
      }
      else
        return false;
    }
    return true;
  }

	public boolean checkConfig() {
		return checkConfig(null);
	}

	public boolean checkConfig(Frame parent) {

		if (!super.checkConfig())
			return false;

		if (HostAddresses.empty()) {
			if (parent != null)
      	UserDialog.ErrorBox("No addresses assigned to host!");
			return false;
		}

		if (HostAddresses.hasBroadcastAddr() || HostAddresses.hasNetworkAddr()) {
			if (parent != null)
      	UserDialog.ErrorBox("Network or broadcast address assigned to host!");
			return false;
		}
		return true;
	}

	public boolean canConnectTo(DragDropObj ddo) {
		if (ddo instanceof Host)
			return false;
		return true;
	}

	public void connectError(Frame parent) {
    UserDialog.ErrorBox("Can't connect two hosts!");
		return;
	}

	public void setOKIcon(DragDrop dd) {
		if (dd != null)
			erase(dd.getCanvasGraphics(), dd.offset_x, dd.offset_y);
		if (isFirewall) {
			if (bFirewallSource == null)
				bFirewallSource = new cpuFirewallImageSource();
			icon = Toolkit.getDefaultToolkit().createImage(bFirewallSource);
		}
		else {
			if (bServerSource == null)
				bServerSource = new cpuServerImageSource();
			icon = Toolkit.getDefaultToolkit().createImage(bServerSource);
		}
		if (dd != null)
			draw(dd.getCanvasGraphics(), dd.offset_x, dd.offset_y);
 	}	

	public void setNOKIcon(DragDrop dd) {
		if (dd != null)
			erase(dd.getCanvasGraphics(), dd.offset_x, dd.offset_y);
    if (bCpuSource == null)
    	bCpuSource = new cpu1ImageSource();
    icon = Toolkit.getDefaultToolkit().createImage(bCpuSource);
		if (dd != null)
			draw(dd.getCanvasGraphics(), dd.offset_x, dd.offset_y);
	} 


  /**
   * Show the host properties dialog. The drag and drop panel calls this
   * method when the user double clicks on the host icon in edit mode.
   * @param parent Parent frame (drag and drop panel)
   */
  public void execute(DragDrop dd) {
    HostProperties hp;
		Frame parent = Utils.getParentFrame(dd);
		
    if (objectID.length() > 0)
      hp = new HostProperties(parent, "Host "+objectID, this);
    else
      hp = new HostProperties(parent, "Host properties", this);
    hp.setVisible(true);
		if(checkConfig(parent)) // check consistency
			setOKIcon(dd);
		else 
			setNOKIcon(dd);
  }

  /**
   * Show the firewall action window. The drag and drop panel calls this
   * method when the user double click on the host icon and edit mode
   * is diabled.
   * @param parent Parent frame (drag and drop panel)
   * @param g Graphics context of the drag and drop canvas
   * @param x_offset Horizontal offset of the virtual viewport
   * @param y_offset Vertical offset of the virtual viewport
   */
  public void userAction(Frame parent, Graphics g, int x_offset, int y_offset) {
    if (!isFirewall) {
      UserDialog.NoticeBox("This is not a firewall!");
      return;
    }
    parent.setCursor(new Cursor(Cursor.WAIT_CURSOR));

		Connection conn = Communicator.openServer(HostAddresses.getFirstAddress());
    if (conn == null) {
      UserDialog.ErrorBox("Cannot connect to "+
        Communicator.resolveIP(HostAddresses.getFirstAddress()));
      parent.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
      return;
    }
    if (actionFrame == null) {
      actionFrame = new FirewallAction(this);
      Dimension screensize = Toolkit.getDefaultToolkit().getScreenSize();
      actionFrame.setSize(screensize.width/6*5, screensize.height/4*3); 
    }
    actionFrame.setVisible(true);
    parent.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
  }

  /**
   * Generate firewall configuration file and write it to the firewall
   * @return true on success, false otherwise
   */
  public boolean generateConfig() {
    if (!isFirewall)
      return false;
    try {
      ServerOutputStream ros = new ServerOutputStream
        (HostAddresses.getFirstAddress(), ManageControl.custom.getProperty("GENERATE_CONFIG"));
      PrintWriter ps = new PrintWriter(ros, true);

      ps.println("#");
      ps.println("# sf firewall configuration file");
      ps.println("# ------------------------------");
      ps.println("# automatically generated "+(new Date())+" for "+objectID);
      ps.println("# DO NOT EDIT THIS FILE!");
      ps.println("#");
      ps.println();

      ps.println("setup");
      ps.println();
      if (!internalAddresses.empty()) {
        ps.println("internalnets");
        internalAddresses.printAddressesFormatted(ps, 2, Macro.MACRO_FIRSTPORT, Macro.MACRO_LASTPORT);
        ps.println(";");
        ps.println();
      }
      ps.println("mail_default \""+mgDomain.defaultMail+"\";");
      ps.println();

      int ownidx = mgDomain.Firewalls.indexOf(this);
      Enumeration en = mgDomain.Rules.elements();
      Rule r;
      boolean hasRules = false;
      while (en.hasMoreElements()) {
        r = (Rule)en.nextElement();
        if (r.priority && r.validFor[ownidx]) {
          if (!hasRules) {
            hasRules = true;
            ps.println("priority_rules");
            ps.println();
          }
          r.printRule(ps, mgDomain, this);
        }
      }

      ps.println("rules");
      ps.println();
      en = mgDomain.Rules.elements();
      while (en.hasMoreElements()) {
        r = (Rule)en.nextElement();
        if (!r.priority && r.validFor[ownidx])
          r.printRule(ps, mgDomain, this);
      }

      ps.println("notification");
      ps.println();
      Notification.printAllLevels(ps, mgDomain.NLevels);

      ps.println("end.");

      ros.close();
      ps.close();

      return Communicator.checkConfig(HostAddresses.getFirstAddress());
    } // try
    catch (Exception e) {
      return false;
    }
  }

  /**
   * Reconfigure firewall. 
   * @return true on success, false otherwise
   */
  public boolean reconfig() {
    return Communicator.reconfig(HostAddresses.getFirstAddress());
  }
  // persistence methods
  /**
   * Write object data to a persistent output stream
   * @param ps Stream
   * @see PersistentOutputStream
   */
  public void write(PersistentOutputStream ps) {
    super.write(ps);
    ps.writePersistent("HostAddresses=", HostAddresses);
    ps.writePersistent("internalAddresses=", internalAddresses);
    ps.writeBoolean("isFirewall=", isFirewall);
    ps.writeBoolean("transparent=", transparent);
    ps.writeBoolean("isServer=", isServer);
    ps.writeBoolean("publicServer=", publicServer);
    ps.writeInt("NumberOfTemplates=", hostTemplates.length);
    for (int i=0; i < hostTemplates.length; i++)
      ps.writeBoolean("TemplateItem=", hostTemplates[i]);
  }

  /**
   * Read object data from a persistent input stream
   * @param ps Stream
   * @see PersistentInputStream
   */
  public void read(PersistentInputStream ps) throws java.io.IOException {
    super.read(ps);
    HostAddresses = (AddrList)ps.readPersistent("HostAddresses=");
    internalAddresses = (AddrList)ps.readPersistent("internalAddresses=");
    isFirewall = ps.readBoolean("isFirewall=");
    transparent = ps.readBoolean("transparent=");
    isServer = ps.readBoolean("isServer=");
    publicServer = ps.readBoolean("publicServer=");
    int tlen = ps.readInt("NumberOfTemplates=");
    boolean btmp[] = new boolean[tlen];
    for (int i=0; i < tlen; i++)
      btmp[i] = ps.readBoolean("TemplateItem=");
    if (tlen == hostTemplates.length)
      hostTemplates = btmp;
  }


  // overriding Object methods

  /**
   * @return string describing the host
   */
  public String toString() {
    return "Host: "+objectInfo();
  }

  private static java.awt.image.ImageProducer bCpuSource = null;
  private static java.awt.image.ImageProducer bFirewallSource = null;
  private static java.awt.image.ImageProducer bServerSource = null;

  // host properties
	protected boolean isConsistent = false;	// is configuration consistent?
  protected AddrList HostAddresses = new AddrList();
  protected AddrList internalAddresses = null; // automatically calculated
  protected boolean isFirewall = false; // is this host a firewall?
  protected boolean transparent = true; // route traffic from outside to outside
  protected boolean isServer = false; // is this host a server (e.g.WWW) ?
  protected boolean publicServer = true; // is this server a public server, 
                                         // i.e. access from the internet allowed?
  protected boolean hostTemplates[];

  // variables for sfc show data
  protected transient boolean isLoaded = false;
  protected transient byte addr[][];
  protected transient byte mask[][];
  protected transient short port[];
  protected transient short prend[];
  protected transient Vector rules;
  protected transient String varnames[];
  protected transient int varvalues[][];
  protected transient byte varaddr[][][];
  protected transient Date vartimeout[][];
  protected transient Vector tcpconns;
  protected transient Date actDate; // server time and date when reading tcp connections

  private transient FirewallAction actionFrame = null;

} // Host

// Dialog to enter the host settings
class HostProperties
	extends Dialog
	implements ActionListener, ItemListener, TextListener {

  public HostProperties(Frame parent, String title, Host hst) {
    super(parent, title, true);
    host = hst;
    GridBagLayout gbl = new GridBagLayout();
    GridBagConstraints gbc = new GridBagConstraints();
    gbc.fill = GridBagConstraints.BOTH;
    gbc.insets = new Insets(5,5,5,5);
    setLayout(gbl);

    // Name panel
    Utils.add_component(this, new JLabel(new ImageIcon(host.icon)),
	 										gbl, gbc, 0, 0, 1, 1, 0, 0);
    Utils.add_component(this, new Label("Identifier: "),
	 										gbl, gbc, 1, 0, 1, 1, 0, 0);
    IDtext = new TextField(host.objectID);
	 IDtext.addTextListener(this);
    Utils.add_component(this, IDtext, gbl, gbc, 2, 0, 3, 1, 100, 0);

    // Address panel
    Panel ap = host.HostAddresses.editPanel();
    Utils.add_component(this, ap, gbl, gbc, 0, 1, 3, 8, 80, 100);

    // Host type panel
    FirewallBox = new Checkbox("Firewall", host.isFirewall);
	 FirewallBox.addItemListener(this);
    FirewallMore = new Button("More...");
	 FirewallMore.addActionListener(this);
    Utils.add_component(this, FirewallBox, gbl, gbc, 3, 2, 1, 1, 0, 0);
    Utils.add_component(this, FirewallMore, gbl, gbc, 4, 2, 1, 1, 0, 0);
    ServerBox = new Checkbox("Server", host.isServer);
	 ServerBox.addItemListener(this);
    ServerMore = new Button("More...");
	 ServerMore.addActionListener(this);
    Utils.add_component(this, ServerBox, gbl, gbc, 3, 3, 1, 1, 0, 0);
    Utils.add_component(this, ServerMore, gbl, gbc, 4, 3, 1, 1, 0, 0);

    // Buttons
    OKbutton = new Button("OK");
	 OKbutton.addActionListener(this);
    gbc.fill = GridBagConstraints.NONE;
    Utils.add_component(this, OKbutton, gbl, gbc, 0, 9, 5, 1, 0, 0);

    // Window size
    Graphics g = parent.getGraphics();
    FontMetrics fm = g.getFontMetrics();
    setSize(fm.stringWidth("255.255.255.255/255.255.255.255   ") * 2,
           fm.getHeight() * 20 );
    g.dispose();
	 addWindowListener(new HPAdapter());
  }


  // Handle Windowclosing
class HPAdapter extends WindowAdapter {
  	public void WindowClosing(WindowEvent we) {
      if (isEnabled())
        dispose();
      return;
	}
} // HPAdapter


	// Process Buttons
  public void actionPerformed(ActionEvent ae) {
  Object source = ae.getSource();

	 // Process OKbutton
    if (source==OKbutton) {  
      host.objectID = IDtext.getText().trim();
      dispose();
      return;
    }

	 // Process FirewallMore
    else if (source==FirewallMore) {
      if (host.isFirewall) {
        AutoconfSettings as = new AutoconfSettings(
          Utils.getParentFrame(this), "Firewall Settings", host, 
          Templates.startFirewall, Templates.numberFirewall);
        as.setVisible(true);
      }
      return;
    }

	 // Process ServerMore
    else if (source==ServerMore) {
      if (host.isServer) {
        AutoconfSettings as = new AutoconfSettings( 
          Utils.getParentFrame(this), "Server Settings", host, 
          Templates.startServer, Templates.numberServer);
        as.setVisible(true);
      } 
      return;
    }
  } // actionPerformed


	// Process Checkboxes
  public void itemStateChanged(ItemEvent ie) {
  Object source = ie.getSource();

	 // Process FirewallBox
    if (source==FirewallBox) {
      host.isFirewall = FirewallBox.getState();
      return;
    }

	 // Process ServerBox
    else if (source==ServerBox) {
      host.isServer = ServerBox.getState();
      return;
    }
  } // itemStateChanged


  // Process TextFields
  public void textValueChanged(TextEvent te) {
  Object source = te.getSource();

	 // Process IDtext
    if (source==IDtext) {
      host.objectID = (((TextComponent)source).getText().trim());
      setTitle("Host "+host.objectID);
      return;
    }
  } // textValueChanged

	public boolean isFirewall() {

		return FirewallBox.getState();
	} // isFirewall

  private Host host;
  private Button OKbutton;
  private TextField IDtext;
  private Checkbox FirewallBox;
  private Checkbox ServerBox;
  private Button FirewallMore;
  private Button ServerMore;
} // HostProperties

// Dialog to enter the firewall and server access profiles
class AutoconfSettings
	extends Dialog
	implements ActionListener, ItemListener {

  public AutoconfSettings(Frame p, String title, Host hst, int st, int no) {
    super(p, title, true);
    start = st;
    number = no;
    host = hst;
    GridBagLayout gbl = new GridBagLayout();
    GridBagConstraints gbc = new GridBagConstraints();
    gbc.fill = GridBagConstraints.BOTH;
    gbc.insets = new Insets(5,5,5,5);
    setLayout(gbl);

    // Checkboxes
    gbc.fill = GridBagConstraints.NONE;
    gbc.anchor = GridBagConstraints.NORTHWEST;

    if (start == Templates.startServer) { // server dialog
      publicServerBox = new Checkbox("Public access to this server",
											host.publicServer);
		publicServerBox.addItemListener(this);
      Utils.add_component(this, publicServerBox, gbl, gbc, 0, 0, 4, 1, 0, 0);
    }

    if (start == Templates.startFirewall) { // firewall dialog
      transparentBox = new Checkbox("Allow packets from outside to outside",
												host.transparent);
		transparentBox.addItemListener(this);
      Utils.add_component(this, transparentBox, gbl, gbc, 0, 0, 4, 1, 0, 0);
    }

    CheckboxArray = new Checkbox[number];
    int half = (int)Math.floor(((double)number / 2.0) + 0.5);
    for (int i=start; i < start + number; i++) {
      CheckboxArray[i-start] = new Checkbox(Templates.prompt[i],
										host.hostTemplates[i-Templates.startServer]);
		CheckboxArray[i-start].addItemListener(this);
      if (i-start < half)
        Utils.add_component(this, CheckboxArray[i-start], gbl, gbc, 
                            0, i-start+1, 2, 1, 0, 0);
      else
        Utils.add_component(this, CheckboxArray[i-start], gbl, gbc, 
                            2, i-start-half+1, 2, 1, 0, 0);
    }

    // Buttons
    OKbutton = new Button("OK");
	 OKbutton.addActionListener(this);
    Utils.add_component(this, OKbutton, gbl, gbc, 0, half+1, 4, 1, 0, 0);

    // Window size
    pack();
	 addWindowListener(new ASAdapter());
  }

	// Handle Windowclosing
class ASAdapter extends WindowAdapter {
  	public void WindowClosing(WindowEvent we) {
      if (isEnabled())
        dispose();
      return;
	}
} // class ASAdapter


	// Process Buttons
  public void actionPerformed(ActionEvent ae) {
  Object source = ae.getSource();

    if (source==OKbutton) {
      dispose();
      return;
    }
  } // actionPerformed


	// Process Checkboxes
  public void itemStateChanged(ItemEvent ie) {
  Object source = ie.getSource();

    if (source == publicServerBox) {
      host.publicServer = publicServerBox.getState();
      return;
    }
    else if (source == transparentBox) {
      host.transparent = transparentBox.getState();
      return;
    }
    else if (source instanceof Checkbox) {
      for (int i=start; i < start+number; i++) 
        if (source==CheckboxArray[i-start])
          host.hostTemplates[i-Templates.startServer] = CheckboxArray[i-start].getState();
      return;
    }
  } //itemStateChange


  private Host host;
  int start;
  int number;

  private Checkbox publicServerBox;
  private Checkbox transparentBox;
  private Checkbox CheckboxArray[]; 
  private Button OKbutton;

} // AutoconfSettings

// HostIcon
class cpu1ImageSource extends java.awt.image.MemoryImageSource {

  final static int bWidth = 40;
  final static int bHeight = 40;
  private static int[] bPixels = { // color model is AARRGGBB


    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffab1700, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffab1700, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffab1700, 0xffab1700, 0xffab1700,
    0xffbebebe, 0xffbebebe, 0xffab1700, 0xffab1700, 0xffab1700,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffab1700, 0xffab1700,
    0xffab1700, 0xffab1700, 0xffab1700, 0xffab1700, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffab1700,
    0xffab1700, 0xffab1700, 0xffab1700, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffab1700,
    0xffab1700, 0xffab1700, 0xffab1700, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffab1700, 0xffab1700,
    0xffab1700, 0xffab1700, 0xffab1700, 0xffab1700, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xff000000, 0xffbebebe, 0xffab1700, 0xffab1700, 0xffab1700,
    0xffbebebe, 0xffbebebe, 0xffab1700, 0xffab1700, 0xffab1700,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffab1700, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffab1700, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000, 0xff6e6e6e,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff6e6e6e, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffbebebe,
    0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xffbebebe,
    0xff6e6e6e, 0xffbebebe, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff000000, 0xffbebebe, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffbebebe, 0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xffe7e7e7, 0xff000000,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xff000000, 0xff6e6e6e,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff000000, 0xffbebebe, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffe7e7e7, 0xffbebebe, 0xff000000, 0xff000000,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff6e6e6e,
    0xff000000, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xff000000,
    0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    };

  public cpu1ImageSource() {
    super( bWidth, bHeight, bPixels, 0, bWidth );
  }
}


// Configured Server Icon
class cpuServerImageSource extends java.awt.image.MemoryImageSource {

  final static int bWidth = 40;
  final static int bHeight = 40;
  private static int[] bPixels = { // color model is AARRGGBB


    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff00af00, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00, 0xff00af00,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00, 0xff00af00,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00, 0xff00af00,
    0xff00af00, 0xffbebebe, 0xff00af00, 0xff00af00, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xffbebebe, 0xff00af00, 0xff00af00, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xff00af00, 0xff00af00, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffe7e7e7, 0xff007b7b, 0xff007b7b, 0xff007b7b,
    0xff007b7b, 0xff007b7b, 0xff007b7b, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff00af00, 0xff00af00, 0xff00af00, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffe7e7e7, 0xff007b7b, 0xff007b7b, 0xff007b7b,
    0xff007b7b, 0xff007b7b, 0xff007b7b, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff00af00, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff007b7b, 0xff007b7b, 0xff007b7b, 0xff007b7b,
    0xff007b7b, 0xff007b7b, 0xff007b7b, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff007b7b, 0xff007b7b, 0xff007b7b, 0xff007b7b,
    0xff007b7b, 0xff007b7b, 0xff007b7b, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000, 0xff6e6e6e,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff6e6e6e, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffbebebe,
    0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xffbebebe,
    0xff6e6e6e, 0xffbebebe, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff000000, 0xffbebebe, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffbebebe, 0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xffe7e7e7, 0xff000000,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xff000000, 0xff6e6e6e,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff000000, 0xffbebebe, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffe7e7e7, 0xffbebebe, 0xff000000, 0xff000000,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff6e6e6e,
    0xff000000, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xff000000,
    0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    };

  public cpuServerImageSource() {
    super( bWidth, bHeight, bPixels, 0, bWidth );
  }
}

// Configured Firewall Icon
class cpuFirewallImageSource extends java.awt.image.MemoryImageSource {

  final static int bWidth = 40;
  final static int bHeight = 40;
  private static int[] bPixels = { // color model is AARRGGBB

    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff00af00, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00, 0xff00af00,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00, 0xff00af00,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00, 0xff00af00,
    0xff00af00, 0xffbebebe, 0xff00af00, 0xff00af00, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xffbebebe, 0xff00af00, 0xff00af00, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xff00af00,
    0xff00af00, 0xff00af00, 0xff00af00, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffe7e7e7, 0xffc31700, 0xffc31700, 0xffc31700,
    0xffc31700, 0xffc31700, 0xffc31700, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff00af00, 0xff00af00, 0xff00af00, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffe7e7e7, 0xffc31700, 0xffc31700, 0xffc31700,
    0xffc31700, 0xffc31700, 0xffc31700, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff00af00, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffc31700, 0xffc31700, 0xffc31700, 0xffc31700,
    0xffc31700, 0xffc31700, 0xffc31700, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xffc31700, 0xffc31700, 0xffc31700, 0xffc31700,
    0xffc31700, 0xffc31700, 0xffc31700, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000, 0xff6e6e6e,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffe7e7e7,
    0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff000000, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff6e6e6e, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xff6e6e6e,
    0xffbebebe, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff000000,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xffbebebe,
    0xff6e6e6e, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xffbebebe, 0xffbebebe,
    0xff6e6e6e, 0xffbebebe, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xff000000, 0xffbebebe, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffbebebe, 0xff000000, 0xff000000, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xffe7e7e7, 0xff000000,
    0xffbebebe, 0xff000000, 0xffbebebe, 0xff000000, 0xff6e6e6e,
    0xff6e6e6e, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff000000, 0xffbebebe, 0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xffe7e7e7, 0xffbebebe, 0xff000000, 0xff000000,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000,
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff6e6e6e,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xff000000, 0xff000000, 0xff6e6e6e, 0xff6e6e6e,
    0xff000000, 0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000,
    0xff000000, 0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xff000000,
    0xff6e6e6e, 0xff6e6e6e, 0xff000000, 0xff000000, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7, 0xffe7e7e7,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xffe7e7e7, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe, 0xffbebebe,
    0xffbebebe, 0xffbebebe, 0xffbebebe, 0xff6e6e6e, 0xff6e6e6e,
    0xffe7e7e7, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e, 0xff6e6e6e,
    };

  public cpuFirewallImageSource() {
    super( bWidth, bHeight, bPixels, 0, bWidth );
  }
}
